NIDM-Results export
===================

Python toolbox to write out neuroimaging statistical results using the NeuroImaging Data
Model (`NIDM Results`_).

.. _NIDM Results: http://nidm.nidash.org/specs/nidm-results.html
